module CommandHelper
  extend Forwardable

  def_delegators :subject, :buffer, :column, :cursor, :line, :window

  def self.included(spec)
    spec.class_eval do
      subject { described_class.new(editor) }
      let(:editor) { TextEditor.new(args).tap(&:bootstrap) }
      let(:args) { [] }
    end
  end

  def expect_buffer(content)
    expect(buffer.to_s).to eq(content)
  end

  def expect_cursor(line, column)
    expect(cursor.position).to eq([line, column])
  end

  def expect_mode(mode)
    expect(editor.mode.name).to eq(mode)
  end

  def update_buffer(content)
    new_buffer = buffer

    content.each_line.map(&:chomp).each.with_index do |line, index|
      method = index.zero? ? :replace_line : :insert_line
      new_buffer = new_buffer.send(method, index, line)
    end

    window.update(new_buffer, cursor)
    expect_buffer(content)
  end

  def update_cursor(line, column)
    new_cursor = cursor.move(line, column)
    window.update(buffer, new_cursor)
    expect_cursor(line, column)
  end
end
