require "spec_helper"

RSpec.describe TextEditor::Command::Backspace do
  include CommandHelper

  describe "#run" do
    context "with an empty buffer" do
      before do
        expect_buffer("")
        expect_cursor(0, 0)
      end

      it "does not change buffer or cursor" do
        subject.run
        expect_buffer("")
        expect_cursor(0, 0)
      end
    end

    context "with a one line buffer" do
      before { update_buffer("ab") }

      it "deletes a character and moves cursor" do
        update_cursor(0, 2)

        subject.run
        expect_cursor(0, 1)
        expect_buffer("a")

        subject.run
        expect_cursor(0, 0)
        expect_buffer("")
      end

      it "does not change buffer if cursor is at start of line" do
        expect_cursor(0, 0)
        subject.run
        expect_cursor(0, 0)
        expect_buffer("ab")
      end
    end

    context "with a multi line buffer" do
      before { update_buffer("ab\ncd") }

      it "backspaces to previous line" do
        update_cursor(1, 0)
        subject.run
        expect_cursor(0, 2)
        expect_buffer("abcd")
      end
    end
  end
end
