require "spec_helper"

RSpec.describe TextEditor::Command::CursorRightAndInsert do
  include CommandHelper

  let(:args) { %w(--flavor vim) }

  before { expect_mode(:normal) }
  after { expect_mode(:insert) }

  describe "#run" do
    context "with an empty buffer" do
      before do
        expect_buffer("")
        expect_cursor(0, 0)
      end

      it "does not move cursor" do
        subject.run
        expect_buffer("")
        expect_cursor(0, 0)
      end
    end

    context "with an non-empty buffer" do
      before { update_buffer("ab") }
      after { expect_buffer("ab") }

      it "moves cursor to the right" do
        subject.run
        expect_cursor(0, 1)
      end

      it "only moves one column past the end of the line" do
        subject.run
        expect_cursor(0, 1)

        subject.run
        expect_cursor(0, 2)

        subject.run
        expect_cursor(0, 2)
      end
    end

    context "with a buffer containing multiple lines" do
      before do
        update_buffer("ab\ncd")
        update_cursor(0, 2)
      end

      it "does not wrap to next line" do
        subject.run
        update_cursor(0, 2)
      end
    end
  end
end
