require "spec_helper"

RSpec.describe TextEditor::Command::CursorStartWithoutWhitespace do
  include CommandHelper

  describe "#run" do
    context "with an empty buffer" do
      before do
        expect_buffer("")
        expect_cursor(0, 0)
      end

      it "does not move cursor" do
        subject.run
        expect_buffer("")
        expect_cursor(0, 0)
      end
    end

    context "with an non-empty buffer" do
      before do
        update_buffer("ab cd")
        update_cursor(0, 4)
      end

      it "moves cursor to the beginning of the line" do
        subject.run
        expect_buffer("ab cd")
        expect_cursor(0, 0)
      end
    end

    context "with an non-empty buffer prefixed with whitespace" do
      before do
        update_buffer("\t  ab cd")
        update_cursor(0, 7)
      end

      it "moves cursor to the first non-whitespace character" do
        subject.run
        expect_buffer("\t  ab cd")
        expect_cursor(0, 3)
      end
    end
  end
end
