require "spec_helper"

RSpec.describe TextEditor::Configuration::OperatingSystem do
  subject { described_class.new(version) }

  describe "#type" do
    context "cygwin" do
      let(:version) { "some-cygwin-version" }

      it "parses correct type" do
        expect(subject.type).to eq(:Cygwin)
      end
    end

    context "linux" do
      let(:version) { "i686-linux" }

      it "parses correct type" do
        expect(subject.type).to eq(:Linux)
      end
    end

    context "mac" do
      let(:version) { "x86_64-darwin14" }

      it "parses correct type" do
        expect(subject.type).to eq(:Mac)
      end
    end

    context "unknown" do
      let(:version) { "some-other-version" }

      it "parses correct type" do
        expect(subject.type).to eq(:Unknown)
      end
    end

    context "windows" do
      let(:version) { "some-mswin-version" }

      it "parses correct type" do
        expect(subject.type).to eq(:Windows)
      end
    end
  end

  describe "#version" do
    let(:version) { "example" }

    it "returns initialized version" do
      expect(subject.version).to eq(version)
    end
  end
end
